@@ -115,22 +115,21 @@ class image_sync(JobServerPlugin):
         with open(self.imageDir + '/image-versions', "w") as vfile:
           vfile.write(json.dumps(imgVersions))
 
-        # tell the MPCC we can host this file
-        print(f"Adding ourself to mPCC for image {image}")
-        jobservers = []
-        for jobserver in currJobServers:
-          jobservers.append(jobserver)
-        # now append our id
-        jobservers.append(self.js.id)
-        data = {
-          'slug': image,
-          'needs_rebuild': False,
-          'jobservers': jobservers,
-        }
-        response = self.js.session.patch(self.js.mprovURL + 'systemimages/' + str(data['slug']) + '/', data=json.dumps(data))
-        print(f"Image {image} updated.")
-      else:
-        print(f"Image {image} up to date.")
+      # tell the MPCC we can host this file
+      print(f"Adding ourself to mPCC for image {image}")
+      jobservers = []
+      for jobserver in currJobServers:
+        jobservers.append(jobserver)
+      # now append our id
+      jobservers.append(self.js.id)
+      data = {
+        'slug': image,
+        'needs_rebuild': False,
+        'jobservers': jobservers,
+      }
+      response = self.js.session.patch(self.js.mprovURL + 'systemimages/' + str(data['slug']) + '/', data=json.dumps(data))
+      print(f"Image {image} updated.")
+    
 
     # Clean up any directories that are not in our imageList.
     print("Scanning for haning images... " + self.imageDir)
